/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
import dk.nsp.mingraviditet.MinGraviditetFlavor

plugins {
    id("mingraviditet.android.library")
    id("mingraviditet.android.library.jacoco")
    id("mingraviditet.android.hilt")
    alias(libs.plugins.android.junit5) apply false
    id("kotlin-parcelize")
    id("kotlinx-serialization")
}

android {
    testOptions {
        unitTests {
            isIncludeAndroidResources = true
        }
    }

    productFlavors {
        MinGraviditetFlavor.values().forEach {
            getByName(it.name) {
                val (allowLogNetwork, cmsEndpoint) = when (it) {
                    MinGraviditetFlavor.staging2,
                    MinGraviditetFlavor.googlePlay,
                    -> false to "https://graviditetscms.sundhedsdata.dk/wp-json/graviditet/v1/"

                    else -> true to "https://graviditetscms.sundhedsdata.dk/wp-json/graviditet/v1/test/"
                }

                buildConfigField("Boolean", "AllowLogNetwork", allowLogNetwork.toString())
                buildConfigField("String", "cmsBackendUrl", "\"${cmsEndpoint}\"")

            }
        }
    }

    namespace = "dk.nsp.mingraviditet.api"
}

dependencies {
    // Modules
    implementation(project(":shared"))
    implementation(project(":model"))

    implementation(libs.coroutines.android)
    implementation(libs.kotlinx.serialization.json)

    // Retrofit
    implementation(libs.retrofit)
    implementation(libs.retrofit.kotlin.serialization)
    implementation(libs.okhttp.loggingInterceptor)

    testImplementation(libs.mockK)
    testImplementation(libs.roboelectric)
    testImplementation(libs.okhttp.mockWebServer)
    testImplementation(libs.coroutines.test)
}
