/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.api.appointments.model

import dk.nsp.mingraviditet.model.data.CareplanActivities
import dk.nsp.mingraviditet.model.data.CareplanActivity
import kotlinx.serialization.SerialName
import kotlinx.serialization.Serializable

@Serializable
data class NetworkCareplanActivities(
    val activities: List<NetworkCareplanActivity>,
)

@Serializable
data class NetworkCareplanActivity(
    val id: Int,
    val scheduledString: String,
    val title: String,
    val description: String,
    val untilWeek: Int,
    val performer: Performer,
) {
    @Serializable
    enum class Performer {
        @SerialName("OWN_DOCTOR")
        OwnDoctor,

        @SerialName("HOSPITAL")
        Hospital,

        @SerialName("DUE_DATE")
        DueDate,
    }
}

fun NetworkCareplanActivity.Performer.asExternalModel(): CareplanActivity.Performer = CareplanActivity.Performer.valueOf(name)
fun NetworkCareplanActivity.asExternalModel(): CareplanActivity =
    CareplanActivity(id = id, scheduledString, title, description, untilWeek, performer.asExternalModel())

fun NetworkCareplanActivities.asExternalModel(): CareplanActivities = CareplanActivities(activities.map { it.asExternalModel() })
