/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.api.cms

import dk.nsp.api.cms.models.NetworkArticleCategory
import dk.nsp.api.cms.models.NetworkChecklist
import dk.nsp.api.cms.models.NetworkFAQItem
import dk.nsp.api.cms.models.NetworkPage
import dk.nsp.api.cms.models.NetworkRecommendedArticles
import dk.nsp.api.cms.models.NetworkRedirectArticle
import dk.nsp.api.cms.models.NetworkSearchResult
import dk.nsp.shared.network.ResultWrapper

interface CMSDataSource {
    suspend fun getFAQ(): ResultWrapper<List<NetworkFAQItem>>

    suspend fun getArticleSections(): ResultWrapper<List<NetworkArticleCategory>>

    suspend fun getAfterBirthArticleCategories(afterBirthWeek: Int): ResultWrapper<NetworkRecommendedArticles>

    suspend fun getArticleCategories(week: Int): ResultWrapper<NetworkRecommendedArticles>

    suspend fun searchArticles(query: String): ResultWrapper<List<NetworkSearchResult>>
//    suspend fun searchArticles(query: String): ResultWrapper<List<NetworkArticleCategory>>

    suspend fun getChecklists(): ResultWrapper<List<NetworkChecklist>>

    suspend fun getPageContent(pagePath: String): ResultWrapper<NetworkPage>

    suspend fun getRedirectLink(url: String): String

    suspend fun getRedirectArticle(id: Int): ResultWrapper<NetworkRedirectArticle>
}
