/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021-2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.api.cms.models

import dk.nsp.mingraviditet.model.data.Article
import dk.nsp.mingraviditet.model.data.ArticleCategory
import dk.nsp.mingraviditet.model.data.ArticleSection
import kotlinx.serialization.Contextual
import kotlinx.serialization.SerialName
import kotlinx.serialization.Serializable
import java.time.LocalDateTime

@Serializable
data class NetworkArticleCategory(
    @SerialName("cat_ID") val categoryId: Int,
    val name: String,
    val description: String,
    val icon: String?,
    val articles: List<NetworkArticle>,
    val slug: String,
)

@Serializable
data class NetworkArticle(
    val id: Int,
    val title: String,
    val searchOrder: Int? = null, // Only present when searching
    @Contextual val lastUpdated: LocalDateTime,
    val description: String,
    val content: String?,
    val sections: List<NetworkArticleSection>,
)

@Serializable
data class NetworkArticleSection(
    val id: Int,
    val title: String,
    val searchOrder: Int? = null, // Only present when searching,
    val content: String,
    val weeks: List<String>? = null,
)

@Serializable
data class NetworkRecommendedArticles(
    val currentWeek: List<NetworkArticleCategory>,
    val nextWeek: List<NetworkArticleCategory>?,
)

fun NetworkArticleCategory.asExternalModel(index: Int = 0): ArticleCategory = ArticleCategory(
    id = categoryId,
    order = index,
    name = name,
    description = description,
    icon = icon,
    articles = articles.map(NetworkArticle::asExternalModel),
    slug = slug,
)

fun NetworkArticle.asExternalModel(): Article =
    Article(id, title, searchOrder, lastUpdated, description, content, sections.map(NetworkArticleSection::asExternalModel))

fun NetworkArticleSection.asExternalModel(index: Int = 0): ArticleSection =
    ArticleSection(id = id, title = title, sortOrder = index, searchOrder = searchOrder, content = content, weeks = weeks)
