/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.api.appointments.model

import dk.nsp.mingraviditet.model.data.CareplanActivities
import dk.nsp.mingraviditet.model.data.CareplanActivity
import dk.nsp.testassertions.assertEquals
import kotlinx.serialization.json.Json
import org.junit.Test

class NetworkCareplanActivitiesTest {

    private val networkCareplanActivity = NetworkCareplanActivity(
        id = 1,
        scheduledString = "Uge 6-10",
        title = "Første konsultation hos praktiserende læge",
        description = "Helbredsundersøgelse, samtale og orientering om det videre graviditetsforløb. Henvisning til fødested.",
        untilWeek = 10,
        performer = NetworkCareplanActivity.Performer.OwnDoctor,
    )
    private val networkCareplanActivities = NetworkCareplanActivities(
        activities = listOf(networkCareplanActivity),
    )

    private val externalCareplanActivity = CareplanActivity(
        id = 1,
        scheduledString = "Uge 6-10",
        title = "Første konsultation hos praktiserende læge",
        description = "Helbredsundersøgelse, samtale og orientering om det videre graviditetsforløb. Henvisning til fødested.",
        untilWeek = 10,
        performer = CareplanActivity.Performer.OwnDoctor,
    )
    private val externalCareplanActivities = CareplanActivities(listOf(externalCareplanActivity))

    @Test
    fun testNetworkCareplanActivitiesSerializer() {
        val decoded = Json.decodeFromString<NetworkCareplanActivities>(
            """{ "activities": [
        {
            "scheduledString": "Uge 6-10",
            "title": "Første konsultation hos praktiserende læge",
            "description": "Helbredsundersøgelse, samtale og orientering om det videre graviditetsforløb. Henvisning til fødested.",
            "untilWeek": 10,
            "performer": "OWN_DOCTOR",
            "id": 1
        }]}
            """.trimIndent(),
        )

        decoded.assertEquals(networkCareplanActivities)
    }

    @Test
    fun testNetworkCareplanActivitySerializer() {
        val decoded = Json.decodeFromString<NetworkCareplanActivity>(
            """{
            "scheduledString": "Uge 6-10",
            "title": "Første konsultation hos praktiserende læge",
            "description": "Helbredsundersøgelse, samtale og orientering om det videre graviditetsforløb. Henvisning til fødested.",
            "untilWeek": 10,
            "performer": "OWN_DOCTOR",
            "id": 1
        }""",
        )

        decoded.assertEquals(networkCareplanActivity)
    }

    @Test
    fun testNetworkPerformerAsExternalModel() {
        NetworkCareplanActivity.Performer.OwnDoctor.asExternalModel().assertEquals(CareplanActivity.Performer.OwnDoctor)
        NetworkCareplanActivity.Performer.Hospital.asExternalModel().assertEquals(CareplanActivity.Performer.Hospital)
        NetworkCareplanActivity.Performer.DueDate.asExternalModel().assertEquals(CareplanActivity.Performer.DueDate)
    }

    @Test
    fun testNetworkCareplanActivityAsExternalModel() {
        networkCareplanActivity.asExternalModel().assertEquals(externalCareplanActivity)
    }

    @Test
    fun testNetworkCareplanActivitiesAsExternalModel() {
        networkCareplanActivities.asExternalModel().assertEquals(externalCareplanActivities)
    }
}
