/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.common.compose

import androidx.annotation.DrawableRes
import androidx.compose.foundation.Image
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.text.style.TextAlign
import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.gravidcompose.component.GravidText
import dk.nsp.mingraviditet.gravidcompose.extensions.conditional
import dk.nsp.mingraviditet.gravidcompose.theme.GravidTheme
import dk.nsp.mingraviditet.gravidcompose.utils.GravidPreview

@Composable
private fun StateRow(
    onClick: (() -> Unit)?,
    modifier: Modifier,
    @DrawableRes illustration: Int,
    title: CharSequence,
    description: CharSequence,
) {
    Column(
        modifier = Modifier
            .fillMaxWidth()
            .conditional(onClick != null) {
                clickable { onClick?.invoke() }
            }
            .padding(
                vertical = GravidTheme.dimens.largestSpacing,
            )
            .then(modifier),
        horizontalAlignment = Alignment.CenterHorizontally,
    ) {
        Image(
            painter = painterResource(id = illustration),
            contentDescription = null,
            contentScale = ContentScale.FillWidth,
        )

        GravidText(
            modifier = Modifier
                .fillMaxWidth()
                .padding(horizontal = GravidTheme.dimens.largestSpacing),
            text = title,
            style = GravidTheme.typography.Header4,
            textAlign = TextAlign.Center,
        )
        GravidText(
            modifier = Modifier
                .fillMaxWidth()
                .padding(horizontal = GravidTheme.dimens.largestSpacing),
            text = description,
            textAlign = TextAlign.Center,
        )
    }
}

@Composable
fun ErrorStateRow(
    modifier: Modifier = Modifier,
    title: CharSequence = stringResource(id = R.string.common_alert_title_error),
    description: CharSequence = stringResource(id = R.string.common_alert_message_failed_to_load_data),
    @DrawableRes illustration: Int = R.drawable.ill_error,
    onClick: (() -> Unit)? = null,
) {
    StateRow(onClick, modifier, illustration, title, description)
}

@Composable
fun EmptyStateRow(
    modifier: Modifier = Modifier,
    title: CharSequence,
    description: CharSequence,
    @DrawableRes illustration: Int = R.drawable.ill_empty_state,
    onClick: (() -> Unit)? = null,
) {
    StateRow(onClick, modifier, illustration, title, description)
}

@GravidPreview
@Composable
private fun ErrorRowPreview() {
    GravidTheme {
        Column(verticalArrangement = Arrangement.SpaceBetween) {
            EmptyStateRow(
                title = stringResource(id = R.string.faq_empty_state_title),
                description = stringResource(id = R.string.faq_empty_state_description),
            )

            ErrorStateRow()
        }
    }
}
