/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.common.compose

import androidx.compose.animation.AnimatedVisibility
import androidx.compose.animation.slideIn
import androidx.compose.animation.slideOut
import androidx.compose.foundation.background
import androidx.compose.foundation.clickable
import androidx.compose.foundation.interaction.MutableInteractionSource
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.IntOffset
import dk.nsp.mingraviditet.gravidcompose.component.GravidText
import dk.nsp.mingraviditet.gravidcompose.extensions.bold
import dk.nsp.mingraviditet.gravidcompose.theme.GravidTheme

@Composable
fun InfoBox(
    text: CharSequence,
    isVisible: Boolean,
    modifier: Modifier = Modifier,
) {
    Box(
        modifier = Modifier
            .fillMaxWidth()
            .clickable(interactionSource = MutableInteractionSource(), onClick = { /* I'm here to eat clicks */ }, indication = null)
            .then(modifier),
    ) {
        AnimatedVisibility(
            visible = isVisible,
            enter = slideIn { IntOffset(x = 0, y = it.height) },
            exit = slideOut { IntOffset(x = 0, y = it.height) },
        ) {
            GravidText(
                modifier = Modifier
                    .background(GravidTheme.colorScheme.primary)
                    .padding(GravidTheme.dimens.defaultSpacing),
                text = text,
                style = GravidTheme.typography.Info.bold,
                color = GravidTheme.gravidColorSystem.neutrals.white,
                textAlign = TextAlign.Center,
            )
        }
    }
}
