/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.careplanactivities.compose

import android.content.res.Configuration.UI_MODE_NIGHT_YES
import androidx.compose.foundation.background
import androidx.compose.foundation.isSystemInDarkTheme
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.drawBehind
import androidx.compose.ui.geometry.Offset
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.gravidcompose.component.GravidText
import dk.nsp.mingraviditet.gravidcompose.extensions.bold
import dk.nsp.mingraviditet.gravidcompose.theme.GravidTheme

@Composable
fun ActivityTimelineHeader(
    title: CharSequence,
    backgroundColor: Color = Color.Transparent,
    isBeforeToday: Boolean,
    modifier: Modifier = Modifier,
) {
    val pillBackgroundColor = when (isBeforeToday) {
        true -> if (isSystemInDarkTheme()) GravidTheme.colorScheme.surfaceVariant else GravidTheme.gravidColorSystem.darkMode.comet
        false -> GravidTheme.colorScheme.primary
    }

    val lineColor = GravidTheme.colorScheme.onBackground

    Box(
        modifier = Modifier
            .background(backgroundColor)
            .fillMaxWidth()
            .drawBehind {
                drawLine(
                    color = lineColor,
                    start = Offset(x = 16.dp.toPx(), y = 0f),
                    end = Offset(x = 16.dp.toPx(), y = size.height),
                    strokeWidth = 2.dp.toPx(),
                )
            }
            .padding(vertical = GravidTheme.dimens.defaultSpacing)
            .then(modifier),
    ) {
        Row(
            modifier = Modifier.padding(start = 7.dp),
        ) {
            GravidText(
                modifier = Modifier
                    .height(23.dp)
                    .background(
                        color = pillBackgroundColor,
                        shape = RoundedCornerShape(percent = 50),
                    )
                    .padding(
                        horizontal = GravidTheme.dimens.largeSpacing,
                        vertical = GravidTheme.dimens.trumpSpacing,
                    ),
                text = title,
                style = GravidTheme.typography.Info.bold,
                color = GravidTheme.gravidColorSystem.neutrals.white,
            )
        }
    }
}

@Preview(showBackground = true)
@Preview(showBackground = true, uiMode = UI_MODE_NIGHT_YES)
@Composable
fun AppointmentHeaderPreview() {
    GravidTheme {
        Column {
            ActivityTimelineHeader(title = stringResource(id = R.string.past_appointments_title), isBeforeToday = true)
            ActivityTimelineHeader(title = stringResource(id = R.string.future_appointments_title), isBeforeToday = false)
        }
    }
}
