/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.careplanactivities.navigation

import androidx.navigation.NavController
import androidx.navigation.NavGraphBuilder
import androidx.navigation.NavOptions
import androidx.navigation.NavType
import androidx.navigation.compose.composable
import androidx.navigation.navArgument
import androidx.navigation.navigation
import dk.nsp.mingraviditet.ui.main.careplanactivities.CareplanActivitiesRoute
import dk.nsp.mingraviditet.ui.main.careplanactivities.details.CareplanActivityRoute
import dk.nsp.mingraviditet.ui.main.common.navigation.animatedComposable

const val careplanIdArg = "careplanId"

private const val CAREPLAN_ACTIVITIES_GRAPH_ROUTE = "careplan_activities_graph"
const val careplanActivitiesRoute = "careplan_activities_route"
const val careplanActivityDetailsRoute = "careplan_activity_details_route/{$careplanIdArg}"

fun NavController.navigateToCareplanActivities(navOptions: NavOptions? = null) {
    this.navigate(CAREPLAN_ACTIVITIES_GRAPH_ROUTE, navOptions)
}

fun NavController.navigateToCareplanActivity(activityId: Int) {
    this.navigate("careplan_activity_details_route/$activityId") {
        launchSingleTop = true
    }
}

fun NavGraphBuilder.careplanActivitiesScreen(
    navController: NavController,
) {
    navigation(
        route = CAREPLAN_ACTIVITIES_GRAPH_ROUTE,
        startDestination = careplanActivitiesRoute,
    ) {
        composable(route = careplanActivitiesRoute) {
            CareplanActivitiesRoute(
                onClickActivity = { activityId -> navController.navigateToCareplanActivity(activityId = activityId) },
//                hasAnimatedToCurrentDate = false,
            )
        }

        animatedComposable(
            route = careplanActivityDetailsRoute,
            arguments = listOf(
                navArgument(careplanIdArg) { type = NavType.IntType },
            ),
        ) {
            CareplanActivityRoute(onBackPressed = navController::navigateUp)
        }
    }
}
