/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.common.compose

import android.annotation.SuppressLint
import android.graphics.Color
import android.view.ViewGroup
import android.webkit.WebChromeClient
import android.webkit.WebView
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.toArgb
import androidx.compose.ui.viewinterop.AndroidView
import androidx.core.view.updateLayoutParams
import dk.nsp.mingraviditet.extensions.disable
import dk.nsp.mingraviditet.gravidcompose.theme.GravidTheme
import dk.nsp.mingraviditet.util.android.OpenExternalLinksInBrowserWebViewClient
import dk.nsp.mingraviditet.util.android.WebViewHelper

@SuppressLint("SetJavaScriptEnabled")
@Composable
fun LocalWebView(
    content: String,
    webViewType: WebViewHelper.Type,
    webChromeClient: WebChromeClient? = null,
    onInternalLinkClicked: (String) -> Unit = {},
    onPageFinishedLoading: (String?) -> Unit = {},
    modifier: Modifier = Modifier,
) {
    val toolbarColor = GravidTheme.colorScheme.surface.toArgb()

    AndroidView(
        modifier = modifier,
        factory = { context ->
            WebView(context).apply {
                layoutParams = ViewGroup.LayoutParams(
                    ViewGroup.LayoutParams.MATCH_PARENT,
                    ViewGroup.LayoutParams.MATCH_PARENT,
                )
                isVerticalScrollBarEnabled = false
                isHorizontalScrollBarEnabled = false
                setBackgroundColor(Color.TRANSPARENT)

                // Enable js to be able to show videos
                settings.javaScriptEnabled = webViewType == WebViewHelper.Type.Article
                settings.useWideViewPort = false
                settings.loadWithOverviewMode = false

                webChromeClient?.let { this.webChromeClient = it }

                webViewClient = OpenExternalLinksInBrowserWebViewClient(
                    context = context,
                    customTabsToolbarColor = toolbarColor,
                    onInternalLinkClicked = onInternalLinkClicked,
                    onPageFinished = { onPageFinishedLoading(it) },
                )

                disable()
            }
        },
        update = {
            val htmlToLoad = WebViewHelper.createHtmlWithStyleSheet(
                rawHtml = content,
                type = webViewType,
                context = it.context,
            )

            it.loadDataWithBaseURL(
                "file:///android_asset/",
                htmlToLoad,
                "text/html",
                "UTF-8",
                "",
            )

            it.updateLayoutParams {
                height = ViewGroup.LayoutParams.WRAP_CONTENT
            }
        },
    )
}
