/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.knowledge.articledetails

import android.view.View
import android.view.ViewGroup
import android.webkit.WebChromeClient
import android.widget.FrameLayout
import androidx.core.view.WindowCompat
import androidx.core.view.WindowInsetsCompat
import androidx.core.view.WindowInsetsControllerCompat
import dk.nsp.mingraviditet.util.extensions.findActivity

class FullScreenVideoView {
    private var view: View? = null
    private var originalOrientation: Int = 0
    private var customViewCallback: WebChromeClient.CustomViewCallback? = null

    private fun hideSystemUI() {
        val activity = view?.context?.findActivity() ?: return
        val window = activity.window
        val decorView = window.decorView as FrameLayout

        WindowCompat.setDecorFitsSystemWindows(window, false)
        WindowInsetsControllerCompat(window, decorView).let { controller ->
            controller.hide(WindowInsetsCompat.Type.systemBars())
            controller.systemBarsBehavior = WindowInsetsControllerCompat.BEHAVIOR_SHOW_TRANSIENT_BARS_BY_SWIPE
        }
    }

    private fun showSystemUI() {
        val activity = view?.context?.findActivity() ?: return
        val window = activity.window
        val decorView = window.decorView as FrameLayout

        WindowCompat.setDecorFitsSystemWindows(window, true)
        WindowInsetsControllerCompat(window, decorView).show(WindowInsetsCompat.Type.systemBars())
    }

    fun shownViewInFullScreen(view: View, callback: WebChromeClient.CustomViewCallback) {
        if (this.view != null) {
            hideViewFromFullScreen()
            return
        }

        this.view = view

        val activity = view.context.findActivity() ?: return
        val window = activity.window
        val decorView = window.decorView as FrameLayout

        originalOrientation = activity.requestedOrientation

        customViewCallback = callback

        decorView.addView(this.view, FrameLayout.LayoutParams(ViewGroup.LayoutParams.MATCH_PARENT, ViewGroup.LayoutParams.MATCH_PARENT))

        hideSystemUI()
    }

    fun hideViewFromFullScreen() {
        val activity = view?.context?.findActivity() ?: return
        val window = activity.window
        val decorView = window.decorView as FrameLayout

        view?.let {
            decorView.removeView(it)
        }
        showSystemUI()
        activity.requestedOrientation = originalOrientation
        customViewCallback?.onCustomViewHidden()
        customViewCallback = null
        view = null
    }
}
