/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.knowledge.checklist.compose

import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.lazy.LazyRow
import androidx.compose.foundation.lazy.items
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.unit.dp
import dk.nsp.domain.knowledge.Checklist
import dk.nsp.domain.knowledge.ChecklistItem
import dk.nsp.mingraviditet.gravidcompose.component.GravidCard
import dk.nsp.mingraviditet.gravidcompose.component.GravidText
import dk.nsp.mingraviditet.gravidcompose.extensions.bold
import dk.nsp.mingraviditet.gravidcompose.theme.GravidTheme
import dk.nsp.mingraviditet.gravidcompose.utils.GravidPreview
import dk.nsp.mingraviditet.ui.main.common.compose.InnerCircularCard
import dk.nsp.mingraviditet.ui.main.overview.compose.widget.CircularPregnancyProgressIndicator

@Composable
fun ChecklistCard(
    checklist: Checklist,
    onClick: () -> Unit,
) {
    GravidCard(onClick = onClick) {
        Row(
            modifier = Modifier.fillMaxWidth(),
            horizontalArrangement = Arrangement.spacedBy(GravidTheme.dimens.defaultSpacing),
        ) {
            InnerCircularCard(containerColor = GravidTheme.colorScheme.tertiaryContainer) {
                Box(modifier = Modifier.fillMaxSize()) {
                    CircularPregnancyProgressIndicator(
                        modifier = Modifier.fillMaxSize(),
                        color = GravidTheme.colorScheme.tertiary,
                        progress = checklist.completeness(),
                        strokeWidth = 2.dp,
                    )

                    GravidText(
                        modifier = Modifier.align(Alignment.Center),
                        text = checklist.getPercentageAsString(),
                        style = GravidTheme.typography.Header5,
                        color = GravidTheme.colorScheme.tertiary,
                    )
                }
            }

            Column(modifier = Modifier.fillMaxWidth()) {
                GravidText(text = checklist.title.bold)

                GravidText(text = checklist.completenessAsDivision())
            }
        }
    }
}

@GravidPreview
@Composable
private fun ChecklistCardRowPreview() {
    val checklistItems = (0..5).toList().map {
        ChecklistItem(it.toString(), "Title $it", value = it % 2 == 1, order = it)
    }
    val checklists = (0..5).toList().map {
        Checklist(it.toString(), "Checklist $it", "Description $it", checklistItems)
    }
    GravidTheme {
        LazyRow {
            items(checklists) { checklist ->
                ChecklistCard(checklist = checklist) {
                }
            }
        }
    }
}
