/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.more.settings

import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import dagger.hilt.android.lifecycle.HiltViewModel
import dk.nsp.domain.repository.PregnancyRepository
import dk.nsp.domain.repository.SettingsPagesRepository
import dk.nsp.domain.repository.SettingsRepository
import dk.nsp.mingraviditet.model.misc.SettingSubSectionUrl
import dk.nsp.shared.network.Failed
import dk.nsp.shared.network.Success
import kotlinx.coroutines.flow.MutableStateFlow
import kotlinx.coroutines.flow.SharingStarted
import kotlinx.coroutines.flow.StateFlow
import kotlinx.coroutines.flow.map
import kotlinx.coroutines.flow.stateIn
import kotlinx.coroutines.launch
import javax.inject.Inject

@HiltViewModel
class ConsentViewModel @Inject constructor(
    private val pagesRepository: SettingsPagesRepository,
    private val pregnancyRepository: PregnancyRepository,
    private val settingsRepository: SettingsRepository,
) : ViewModel() {

    private val pagePath = MutableStateFlow(SettingSubSectionUrl.Consent.path)

    val pageResult: StateFlow<SettingsPageUiState> = pagePath.map {
        when (val pageResult = pagesRepository.getPage(SettingSubSectionUrl.Consent.path)) {
            is Failed -> SettingsPageUiState.Failed
            is Success -> SettingsPageUiState.Success(pageResult.value.content)
        }
    }.stateIn(
        scope = viewModelScope,
        started = SharingStarted.WhileSubscribed(5_000),
        initialValue = SettingsPageUiState.Loading,
    )

    fun clearPregnancy(onDone: () -> Unit) = viewModelScope.launch {
        settingsRepository.clearPreferences()
        pregnancyRepository.clearPregnancy()
        onDone()
    }
}
