/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.more.settings

import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.Scaffold
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.stringResource
import androidx.hilt.navigation.compose.hiltViewModel
import androidx.lifecycle.compose.collectAsStateWithLifecycle
import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.gravidcompose.component.GravidTopBar
import dk.nsp.mingraviditet.gravidcompose.theme.GravidTheme
import dk.nsp.mingraviditet.ui.common.compose.EmptyStateRow
import dk.nsp.mingraviditet.ui.common.compose.LoadingScreen
import dk.nsp.mingraviditet.ui.main.common.compose.LocalWebView
import dk.nsp.mingraviditet.util.android.WebViewHelper

@Composable
fun SettingsSubPageWebViewRoute(
    onBackPressed: () -> Unit,
    webViewViewModel: SettingsPageViewModel = hiltViewModel(),
) {
    val pageUiState by webViewViewModel.pageResult.collectAsStateWithLifecycle()
    val titleResId by webViewViewModel.titleResId.collectAsStateWithLifecycle(initialValue = null)
    SettingsSubPageWebViewScreen(
        onBackPressed = onBackPressed,
        state = pageUiState,
        title = titleResId?.let { stringResource(id = it) },
    )
}

@Composable
fun SettingsSubPageWebViewScreen(
    onBackPressed: () -> Unit,
    state: SettingsPageUiState,
    title: String?,
) {
    Scaffold(
        modifier = Modifier.fillMaxSize(),
        containerColor = GravidTheme.colorScheme.background,
        topBar = {
            GravidTopBar(
                title = title ?: "",
                onNavigationClick = onBackPressed,
            )
        },
    ) { padding ->
        when (state) {
            SettingsPageUiState.Failed -> {
                EmptyStateRow(
                    title = stringResource(id = R.string.common_alert_title_error),
                    description = stringResource(id = R.string.common_alert_message_failed_to_load_data),
                )
            }

            SettingsPageUiState.Loading -> LoadingScreen()

            is SettingsPageUiState.Success -> {
                LocalWebView(
                    modifier = Modifier
                        .padding(top = padding.calculateTopPadding())
                        .padding(horizontal = GravidTheme.dimens.largeSpacing),
                    content = state.content,
                    webViewType = WebViewHelper.Type.Subpage,
                )
            }
        }
    }
}
