/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.more.support

import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.PaddingValues
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.rememberScrollState
import androidx.compose.foundation.verticalScroll
import androidx.compose.material3.Scaffold
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.stringResource
import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.gravidcompose.component.GravidCard
import dk.nsp.mingraviditet.gravidcompose.component.GravidDivider
import dk.nsp.mingraviditet.gravidcompose.component.GravidTopBar
import dk.nsp.mingraviditet.gravidcompose.theme.GravidTheme
import dk.nsp.mingraviditet.gravidcompose.utils.GravidIconType
import dk.nsp.mingraviditet.gravidcompose.utils.GravidPreview
import dk.nsp.mingraviditet.ui.common.compose.ChevronListItem
import dk.nsp.mingraviditet.ui.common.compose.HeaderWithIcon

@Composable
fun SupportOverviewScreen(
    onBackPressed: () -> Unit,
    navigateToFaq: () -> Unit,
    navigateToSupport: () -> Unit,
) {
    Scaffold(
        containerColor = GravidTheme.colorScheme.background,
        topBar = {
            GravidTopBar(
                title = stringResource(id = R.string.more_support_title),
                onNavigationClick = onBackPressed,
            )
        },
    ) { innerPadding ->
        Column(
            modifier = Modifier
                .verticalScroll(state = rememberScrollState())
                .padding(innerPadding)
                .padding(GravidTheme.dimens.largeSpacing),
            verticalArrangement = Arrangement.spacedBy(GravidTheme.dimens.largeSpacing),
        ) {
            HeaderWithIcon(
                icon = GravidIconType.Drawable(R.drawable.ic_support),
                title = stringResource(id = R.string.more_support_title),
                description = stringResource(id = R.string.more_support_description),
            )

            GravidCard(
                modifier = Modifier.padding(top = GravidTheme.dimens.defaultSpacing),
                innerPaddingValues = PaddingValues(vertical = GravidTheme.dimens.defaultSpacing),
            ) {
                Column {
                    ChevronListItem(
                        modifier = Modifier.padding(horizontal = GravidTheme.dimens.largeSpacing),
                        title = stringResource(id = R.string.more_support_faq_title),
                        onClick = navigateToFaq,
                    )

                    GravidDivider(modifier = Modifier.padding(horizontal = GravidTheme.dimens.largeSpacing))

                    ChevronListItem(
                        modifier = Modifier.padding(horizontal = GravidTheme.dimens.largeSpacing),
                        title = stringResource(id = R.string.more_support_contact_title),
                        onClick = navigateToSupport,
                    )
                }
            }
        }
    }
}

@GravidPreview
@Composable
private fun SupportOverviewScreenPreview() {
    GravidTheme {
        SupportOverviewScreen(
            onBackPressed = { },
            navigateToFaq = { },
            navigateToSupport = { },
        )
    }
}
