/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.overview.compose

import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.PaddingValues
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.padding
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.layout.layout
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import dk.nsp.mingraviditet.gravidcompose.component.GravidText
import dk.nsp.mingraviditet.gravidcompose.component.GravidTextButton
import dk.nsp.mingraviditet.gravidcompose.theme.GravidTheme

@Composable
fun ArticleHeader(
    title: CharSequence,
    modifier: Modifier = Modifier,
    trailingComponent: (@Composable () -> Unit)? = null,
) {
    Row(
        modifier = modifier.then(Modifier.padding(vertical = if (trailingComponent == null) GravidTheme.dimens.defaultSpacing else 0.dp)),
        verticalAlignment = Alignment.CenterVertically,
    ) {
        GravidText(
            style = GravidTheme.typography.Header4,
            text = title,
        )

        Spacer(Modifier.weight(1f))

        trailingComponent?.let { it() }
    }
}

@Composable
fun ArticleHeader(
    title: CharSequence,
    trailingTitle: CharSequence,
    modifier: Modifier = Modifier,
    trailingOnClick: () -> Unit,
) {
    val largeSpacing = GravidTheme.dimens.largeSpacing
    ArticleHeader(
        modifier = modifier,
        title = title,
        trailingComponent = {
            GravidTextButton(
                modifier = Modifier
                    // Since the we want the text to align at the end, but it uses paddingValues, we place it manually here
                    .layout { measurable, constraints ->
                        val placeable = measurable.measure(constraints.copy(maxWidth = constraints.maxWidth + largeSpacing.roundToPx()))
                        layout(placeable.width, placeable.height) {
                            placeable.place(largeSpacing.roundToPx(), 0)
                        }
                    },
                text = trailingTitle,
                contentPadding = PaddingValues(horizontal = GravidTheme.dimens.largeSpacing),
                onClick = trailingOnClick,
            )
        },
    )
}

@Preview(showBackground = true)
@Composable
fun ArticleHeaderPreview() {
    GravidTheme {
        Column {
            ArticleHeader(
                title = "Relevant lige nu",
                trailingTitle = "Se flere artikler",
                trailingOnClick = {
                },
            )

            ArticleHeader(title = "I næste uge")
        }
    }
}
