/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.overview.compose.widget

import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.Card
import androidx.compose.material3.CardDefaults
import androidx.compose.material3.ColorScheme
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.tooling.preview.PreviewParameter
import androidx.compose.ui.unit.dp
import dk.nsp.mingraviditet.gravidcompose.component.GravidText
import dk.nsp.mingraviditet.gravidcompose.extensions.bold
import dk.nsp.mingraviditet.gravidcompose.theme.GravidTheme
import dk.nsp.mingraviditet.gravidcompose.utils.PreviewColorSchemeProvider

@Composable
fun CardWithLabel(
    label: CharSequence,
    modifier: Modifier = Modifier,
    cardContent: @Composable () -> Unit,
) {
    Column(
        modifier = modifier,
        horizontalAlignment = Alignment.CenterHorizontally,
    ) {
        Card(
            modifier = modifier,
            elevation = CardDefaults.cardElevation(defaultElevation = GravidTheme.dimens.defaultCardElevation),
            colors = CardDefaults.cardColors(
                containerColor = GravidTheme.colorScheme.surfaceVariant,
            ),
            shape = CardDefaults.shape,
        ) {
            Box(
                Modifier.padding(
                    horizontal = GravidTheme.dimens.largeSpacing,
                    vertical = GravidTheme.dimens.defaultSpacing,
                ),
            ) {
                cardContent()
            }
        }
        GravidText(
            modifier = Modifier.padding(top = GravidTheme.dimens.defaultSpacing),
            text = label,
            style = GravidTheme.typography.Info,
            color = GravidTheme.colorScheme.onBackground,
        )
    }
}

@Composable
fun CardWithLabel(
    label: CharSequence,
    cardText: CharSequence,
    modifier: Modifier = Modifier,
) {
    CardWithLabel(
        modifier = modifier,
        label = label,
    ) {
        GravidText(
            style = GravidTheme.typography.Header1,
            text = cardText,
        )
    }
}

@Preview
@Composable
fun CardWithLabelPreview(
    @PreviewParameter(PreviewColorSchemeProvider::class) colorScheme: ColorScheme,
) {
    GravidTheme(overrideColorScheme = colorScheme) {
        Row(
            modifier = Modifier
                .background(GravidTheme.colorScheme.background)
                .padding(GravidTheme.dimens.largeSpacing),
            horizontalArrangement = Arrangement.spacedBy(16.dp),
        ) {
            CardWithLabel(label = "Graviditetsuge") {
                Row {
                    GravidText(
                        modifier = Modifier.alignByBaseline(),
                        text = "39.",
                        style = GravidTheme.typography.Header1.bold,
                    )
                    GravidText(
                        modifier = Modifier.alignByBaseline(),
                        text = "(38 + 5)",
                        style = GravidTheme.typography.Info,
                    )
                }
            }
            CardWithLabel(label = "Måned", cardText = "8.")
        }
    }
}
