/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.overview.compose.widget

import androidx.compose.foundation.Canvas
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.size
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.geometry.Offset
import androidx.compose.ui.geometry.center
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.Dp
import androidx.compose.ui.unit.dp
import dk.nsp.mingraviditet.gravidcompose.theme.GravidTheme
import kotlin.math.cos
import kotlin.math.sin

@Composable
fun FetusWidgetDots(
    modifier: Modifier = Modifier,
    dotSize: Dp = 4.dp,
    content: @Composable () -> Unit,
) {
    Box(
        modifier = Modifier.then(modifier),
        contentAlignment = Alignment.Center,
    ) {
        Canvas(
            modifier = Modifier.fillMaxSize(),
        ) {
            val circleRadius = dotSize.toPx() / 2
            val radius = size.center.x - circleRadius
            val pointsCount = 9
            val stepSize = 360f / pointsCount

            val startX = size.center.x
            val startY = size.center.y

            for (i in 0 until pointsCount) {
                val theta = Math.toRadians(270 + i * stepSize.toDouble())
                val x = startX + (radius * cos(theta)).toFloat()
                val y = startY + (radius * sin(theta)).toFloat()
                drawCircle(
                    color = Color(0xFF989898),
                    radius = circleRadius,
                    center = Offset(x, y),
                )
            }
        }
        content()
    }
}

@Preview
@Composable
fun FetusWidgetDotsPreview() {
    GravidTheme {
        FetusWidgetDots(
            modifier = Modifier.size(240.dp),
        ) {
            FetusProgressWidget()
        }
    }
}
