/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.overview.compose.widget

import androidx.annotation.DrawableRes
import androidx.compose.animation.core.FastOutSlowInEasing
import androidx.compose.animation.core.LinearEasing
import androidx.compose.animation.core.animateFloatAsState
import androidx.compose.animation.core.tween
import androidx.compose.foundation.Image
import androidx.compose.foundation.layout.offset
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.collectAsState
import androidx.compose.runtime.getValue
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.rotate
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.unit.Dp
import androidx.compose.ui.unit.dp
import androidx.hilt.navigation.compose.hiltViewModel

@Composable
fun NoiseAnimatedImage(
    modifier: Modifier = Modifier,
    @DrawableRes imageDrawable: Int,
    stepDurationMillis: Long = 2000L,
    offsetMultiplier: Dp = 30.dp,
    rotationRange: Int = 20,
    noiseViewModel: NoiseAnimatedImageViewModel = hiltViewModel(),
) {
    LaunchedEffect(Unit) {
        noiseViewModel.updateRate = stepDurationMillis
    }

    val noiseTranslation by noiseViewModel.noiseFlow.collectAsState(initial = Pair(0f, 0f))

    val xAnimatedPosition by animateFloatAsState(
        targetValue = noiseTranslation.first,
        animationSpec = tween(durationMillis = stepDurationMillis.toInt(), easing = LinearEasing),
    )

    val yAnimatedPosition by animateFloatAsState(
        targetValue = noiseTranslation.second,
        animationSpec = tween(durationMillis = stepDurationMillis.toInt(), easing = LinearEasing),
    )

    val rotation by animateFloatAsState(
        targetValue = (noiseTranslation.first - noiseTranslation.second) * rotationRange,
        animationSpec = tween(durationMillis = stepDurationMillis.toInt() * 5, easing = FastOutSlowInEasing),
    )

    Image(
        modifier = modifier
            .offset(
                x = offsetMultiplier * xAnimatedPosition,
                y = offsetMultiplier * yAnimatedPosition,
            )
            .rotate(rotation),
        painter = painterResource(id = imageDrawable),
        contentDescription = null,
    )
}
