/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.overview.compose.widget

import androidx.lifecycle.ViewModel
import com.jnoise.opensimplexnoiselib.OpenSimplex2F
import dagger.hilt.android.lifecycle.HiltViewModel
import kotlinx.coroutines.delay
import kotlinx.coroutines.flow.flow
import javax.inject.Inject

@HiltViewModel
class NoiseAnimatedImageViewModel @Inject constructor() : ViewModel() {
    var updateRate: Long = 2000L

    val noiseFlow = flow {
        val noiseMap = getNoiseBitmap()

        noiseMap.forEachIndexed { index, d ->
            emit(Pair(d, noiseMap[noiseMap.size - 1 - index]))
            delay(updateRate)
        }
    }

    private fun getNoiseBitmap(): List<Float> {
        val noise = createHeightmap(1000, 1, 0, 0, 0.1)

        return noise.map { it / 2.0 }.map { it.toFloat() }
    }

    private fun points(width: Int, height: Int, offX: Int, offY: Int, freq: Double): DoubleArray {
        val points = DoubleArray(width * height * 2)
        var i = 0
        for (y in 0 until height) {
            for (x in 0 until width) {
                val xd = (x + offX) * freq
                val yd = (y + offY) * freq
                points[i++] = xd
                points[i++] = yd
            }
        }
        return points
    }

    private fun createHeightmap(width: Int, height: Int, offX: Int, offY: Int, freq: Double): DoubleArray {
        val openSimplex2F = OpenSimplex2F(System.currentTimeMillis())
        val grid = points(width, height, offX, offY, freq)
        return openSimplex2F.noise2(grid, grid.size / 2)
    }
}
