/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.overview.compose.widget

import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.FlowRow
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.tooling.preview.Preview
import dk.nsp.domain.pregnancymodels.GestationAge
import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.gravidcompose.component.GravidText
import dk.nsp.mingraviditet.gravidcompose.extensions.bold
import dk.nsp.mingraviditet.gravidcompose.theme.GravidTheme

@Composable
fun OverviewPregnancyInformationCardsRow(
    pregnancyWeek: Int,
    gestationAge: GestationAge,
    trimester: Int,
    modifier: Modifier = Modifier,
    trailingComponent: @Composable (() -> Unit)? = null,
) {
    FlowRow(
        modifier = Modifier
            .fillMaxWidth()
            .then(modifier),
        horizontalArrangement = Arrangement.spacedBy(
            GravidTheme.dimens.defaultSpacing,
            alignment = Alignment.CenterHorizontally,
        ),
    ) {
        CardWithLabel(
            label = stringResource(id = R.string.overview_week_title),
            cardContent = {
                Row {
                    GravidText(
                        modifier = Modifier.alignByBaseline(),
                        style = GravidTheme.typography.Header1,
                        text = "$pregnancyWeek.",
                    )
                    GravidText(
                        modifier = Modifier
                            .padding(start = GravidTheme.dimens.trumpSpacing)
                            .alignByBaseline(),
                        style = GravidTheme.typography.Info.bold,
                        text = "(${gestationAge.gestationWeek} + ${gestationAge.gestationDays})",
                    )
                }
            },
        )

        CardWithLabel(
            label = stringResource(id = R.string.overview_trimester_title),
            cardText = "$trimester.",
        )

        trailingComponent?.let { it() }
    }
}

@Preview(showBackground = true)
@Composable
fun OverviewPregnancyInformationCardsRowPreview() {
    GravidTheme {
        OverviewPregnancyInformationCardsRow(
            pregnancyWeek = 29,
            gestationAge = GestationAge(28, 4),
            trimester = 2,
        )
    }
}
