/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.overview.datechooser.calendar

import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.KeyboardArrowLeft
import androidx.compose.material.icons.filled.KeyboardArrowRight
import androidx.compose.material3.IconButton
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.semantics.clearAndSetSemantics
import dk.nsp.mingraviditet.gravidcompose.component.GravidIcon
import dk.nsp.mingraviditet.gravidcompose.component.GravidText
import dk.nsp.mingraviditet.gravidcompose.theme.GravidTheme
import dk.nsp.mingraviditet.gravidcompose.utils.GravidPreview

@Composable
internal fun MonthHeader(
    modifier: Modifier = Modifier,
    month: String,
    year: String,
    onNextMonth: (() -> Unit)?,
    onPreviousMonth: (() -> Unit)?,
) {
    Row(
        modifier = modifier.clearAndSetSemantics { },
        verticalAlignment = Alignment.CenterVertically,
        horizontalArrangement = Arrangement.Center,
    ) {
        GravidText(
            modifier = Modifier.weight(1f),
            text = "$month $year",
            style = GravidTheme.typography.Header4,
        )

        IconButton(onClick = onPreviousMonth ?: {}, enabled = onPreviousMonth != null) {
            GravidIcon(
                imageVector = Icons.Default.KeyboardArrowLeft,
                tint = GravidTheme.colorScheme.tertiary.copy(alpha = if (onPreviousMonth == null) 0.5f else 1f),
            )
        }

        IconButton(onClick = onNextMonth ?: {}, enabled = onNextMonth != null) {
            GravidIcon(
                imageVector = Icons.Default.KeyboardArrowRight,
                tint = GravidTheme.colorScheme.tertiary.copy(alpha = if (onNextMonth == null) 0.5f else 1f),
            )
        }
    }
}

@GravidPreview
@Composable
private fun MonthHeaderPreview() {
    GravidTheme {
        Column(Modifier.fillMaxWidth()) {
            MonthHeader(month = "September", year = "2023", onNextMonth = { }, onPreviousMonth = null)
        }
    }
}
