/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.overview.datechooser.calendar.model

import androidx.compose.runtime.mutableStateOf
import dk.nsp.mingraviditet.ui.main.overview.datechooser.calendar.util.getNumberWeeks
import java.time.LocalDate
import java.time.Period
import java.time.YearMonth

class CalendarState {
    var listMonths: List<Month>
        private set

    var initialSelectedDate: LocalDate? = null
    var calendarStartDate: LocalDate = LocalDate.now()
    var calendarEndDate: LocalDate = LocalDate.now().plusWeeks(40)

    private val periodBetweenCalendarStartEnd: Period
        get() = Period.between(
            calendarStartDate,
            calendarEndDate.withDayOfMonth(calendarEndDate.lengthOfMonth()),
        )

    var calendarUiState = mutableStateOf(
        CalendarUiState(minDate = calendarStartDate, maxDate = calendarEndDate),
    )

    init {
        listMonths = updateListMonths()
    }

    private fun updateListMonths(): List<Month> {
        val tempListMonths = mutableListOf<Month>()
        var startYearMonth = YearMonth.from(calendarStartDate)
        for (numberMonth in 0..periodBetweenCalendarStartEnd.toTotalMonths()) {
            val numberWeeks = startYearMonth.getNumberWeeks()
            val listWeekItems = mutableListOf<Week>()
            for (week in 0 until numberWeeks) {
                listWeekItems.add(
                    Week(
                        number = week,
                        yearMonth = startYearMonth,
                    ),
                )
            }
            val month = Month(startYearMonth, listWeekItems)
            tempListMonths.add(month)
            startYearMonth = startYearMonth.plusMonths(1)
        }
        return tempListMonths.toList()
    }

    fun setSelectedDay(newDate: LocalDate?) {
        calendarUiState.value = updateSelectedDay(newDate)
    }

    private fun updateSelectedDay(newDate: LocalDate?): CalendarUiState {
        val currentState = calendarUiState.value

        return currentState.setDate(newDate)
    }

    fun setMinMaxDates(minDate: LocalDate, maxDate: LocalDate) {
        calendarUiState.value = updateMinMaxDate(minDate, maxDate)
    }

    private fun updateMinMaxDate(minDate: LocalDate, maxDate: LocalDate): CalendarUiState {
        val currentState = calendarUiState.value
        val newState = currentState.setMinMaxDate(minDate, maxDate)
        listMonths = updateListMonths()
        return newState
    }
}
