/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.main.overview.navigation

import androidx.compose.ui.window.DialogProperties
import androidx.navigation.NavController
import androidx.navigation.NavGraphBuilder
import androidx.navigation.NavOptions
import androidx.navigation.NavType
import androidx.navigation.compose.composable
import androidx.navigation.compose.dialog
import dk.nsp.mingraviditet.ui.main.overview.compose.OverviewRoute
import dk.nsp.mingraviditet.ui.main.overview.datechooser.DateChooserDialog

const val overviewNavigationRoute = "overview_route"

fun NavController.navigateToOverview(navOptions: NavOptions? = null) {
    this.navigate(overviewNavigationRoute, navOptions)
}

fun NavGraphBuilder.overviewScreen(
    navController: NavController,
    navigateToKnowledge: () -> Unit,
    onArticleClicked: (articleId: Int, sectionId: Int?) -> Unit,
) {
    composable(
        route = overviewNavigationRoute,
    ) {
        OverviewRoute(
            onNavigateToKnowledge = navigateToKnowledge,
            onNavigateToArticleDetails = onArticleClicked,
            onOpenDateChooserDialog = { dateChooserMethod ->
                navController.navigate("date_chooser/${dateChooserMethod.name}") {
                    launchSingleTop = true
                    argument("dateChooserMethodArgKey") { type = NavType.StringType }
                }
            },
        )
    }

    dialog("date_chooser/{dateChooserMethodArgKey}", dialogProperties = DialogProperties(usePlatformDefaultWidth = false)) {
        DateChooserDialog(onDismissRequest = { navController.navigateUp() })
    }
}
