/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.useradmission.login

import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.Lock
import androidx.compose.material3.FilledIconButton
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButtonDefaults
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.paint
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.unit.dp
import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.gravidcompose.component.GravidText
import dk.nsp.mingraviditet.gravidcompose.theme.GravidTheme
import dk.nsp.mingraviditet.ui.main.more.settings.compose.GravidBiometricPrompt

@Composable
fun LoginScreen(
    navigateToOverview: () -> Unit,
) {
    var showBiometricPrompt by remember {
        mutableStateOf(true)
    }

    LaunchedEffect(Unit) {
        showBiometricPrompt = true
    }

    Column(
        Modifier
            .paint(painterResource(id = R.drawable.ill_overview_circles), contentScale = ContentScale.FillBounds),
    ) {
        Column(Modifier.fillMaxSize(), verticalArrangement = Arrangement.Center, horizontalAlignment = Alignment.CenterHorizontally) {
            GravidText(
                text = stringResource(id = R.string.login_title),
                style = GravidTheme.typography.Hero,
                modifier = Modifier.fillMaxWidth(),
                textAlign = TextAlign.Center,
            )

            FilledIconButton(
                onClick = { showBiometricPrompt = true },
                colors = IconButtonDefaults.filledIconButtonColors(
                    containerColor = GravidTheme.colorScheme.primaryContainer,
                    contentColor = GravidTheme.colorScheme.onPrimaryContainer,
                ),
                modifier = Modifier
                    .padding(top = GravidTheme.dimens.largeSpacing)
                    .size(80.dp),
            ) {
                Icon(
                    modifier = Modifier.size(40.dp),
                    imageVector = Icons.Default.Lock,
                    contentDescription = stringResource(id = R.string.settings_protect_app_prompt_login_title),
                )
            }
        }
    }

    GravidBiometricPrompt(
        showBiometricPrompt = showBiometricPrompt,
        title = stringResource(id = R.string.login_with_biometrics),
        onSuccess = {
            showBiometricPrompt = false
            navigateToOverview()
        },
        onError = {
            showBiometricPrompt = false
        },
    )
}
