/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.ui.useradmission.onboarding

import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import dagger.hilt.android.lifecycle.HiltViewModel
import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.ui.useradmission.onboarding.models.OnboardingPage
import kotlinx.coroutines.flow.SharingStarted
import kotlinx.coroutines.flow.flowOf
import kotlinx.coroutines.flow.stateIn
import javax.inject.Inject

@HiltViewModel
class OnboardingViewModel @Inject constructor() : ViewModel() {
    val onboardingPages = flowOf(
        listOf(
            OnboardingPage.Logos(
                logos = listOf(
                    R.drawable.logo_danske_regioner,
                    R.drawable.logo_sd,
                    R.drawable.logo_plo,
                    R.drawable.logo_kl,
                    R.drawable.logo_sds,
                    R.drawable.logo_ministeriet,
                ),
                title = R.string.onboarding_overview_title,
                text = R.string.onboarding_overview_text,
                R.drawable.ill_onboarding_01,
            ),
            OnboardingPage.Default(
                R.string.onboarding_appointments_title,
                R.string.onboarding_appointments_text,
                R.drawable.ill_onboarding_02,
            ),
            OnboardingPage.Default(
                R.string.onboarding_knowledge_title,
                R.string.onboarding_knowledge_text,
                R.drawable.ill_onboarding_03,
            ),
        ),
    )
        .stateIn(
            viewModelScope,
            started = SharingStarted.WhileSubscribed(5_000),
            initialValue = emptyList(),
        )
}
