/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
// Top-level build file where you can add configuration options common to all sub-projects/modules.
import com.github.benmanes.gradle.versions.updates.DependencyUpdatesTask


plugins {
    alias(libs.plugins.android.application) apply false
    alias(libs.plugins.android.library) apply false
    alias(libs.plugins.kotlin.jvm) apply false
    alias(libs.plugins.kotlin.serialization) apply false
    alias(libs.plugins.android.junit5) apply false
    alias(libs.plugins.hilt) apply false
    alias(libs.plugins.ksp) apply false

    alias(libs.plugins.gradle.versions)
    alias(libs.plugins.gradle.versions.update)
}

fun isNonStable(version: String): Boolean {
//    val stableKeyword = listOf("RELEASE", "FINAL", "GA").any { version.toUpperCase().contains(it) }
    val unstableKeyword = listOf("ALPHA", "BETA", "RC").any { version.uppercase().contains(it) }
    val regex = "^[0-9,.v-]+(-r)?$".toRegex()
    return unstableKeyword || regex.matches(version).not()
}

tasks.withType<DependencyUpdatesTask> {
    rejectVersionIf {
        isNonStable(candidate.version)
    }

    checkConstraints = true
    checkBuildEnvironmentConstraints = true

    outputFormatter = "json"
    outputDir = "build/dependencyUpdates"
    reportfileName = "report"
}

versionCatalogUpdate {
    keep {
        // keep versions without any library or plugin reference
        keepUnusedVersions.set(true)
        // keep all libraries that aren't used in the project
        keepUnusedLibraries.set(true)
        // keep all plugins that aren't used in the project
        keepUnusedPlugins.set(true)
    }
}

buildscript {
    fun getCommitCount(): Int {
        val process = Runtime.getRuntime().exec("git rev-list --count HEAD")
        process.waitFor()
        val output = process.inputStream.bufferedReader().use { it.readText().trim() }
        return output.toInt()
    }

    extra.apply {
        // This is required as of Android Studio 4.1, this is required for modules/libraries since VERSION_CODE and VERSION_NAME is no longer included in the generated build config
        // See: https://issuetracker.google.com/issues/158695880
        // Use this field to set the major/minor/patch numbers for the whole app.
        set("versionName", "1.1.0")
        set("versionCode", getCommitCount())
    }

    val libs = extensions.getByType<VersionCatalogsExtension>().named("libs")
    dependencies {
        classpath(libs.findLibrary("android-navigation-gradlePlugin").get())
    }
}

// Clean qa-reports folder when cleaning project
tasks.create("clean").apply {
    delete("${rootProject.rootDir}/qa-reports")
}
