/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.datastore.model

import dk.nsp.mingraviditet.datastore.ChecklistItem
import dk.nsp.mingraviditet.datastore.ProtoChecklist
import dk.nsp.mingraviditet.datastore.model.ChecklistItemDb.Companion.toProto

data class ChecklistDb(
    val id: String,
    val title: String,
    val description: String?,
    val items: List<ChecklistItemDb>,
) {
    companion object {
        fun ChecklistDb.toProto(): ProtoChecklist {
            val items = items.map { it.toProto() }
            val proto = ProtoChecklist.newBuilder()
                .setId(id)
                .setTitle(title)
                .addAllItems(items)

            description?.let { proto.setDescription(it) }

            return proto.build()
        }
    }
}

data class ChecklistItemDb(
    val id: String,
    val title: String,
    val checked: Boolean,
    val order: Int,
) {
    companion object {
        fun ChecklistItemDb.toProto(): ChecklistItem {
            return with(this) {
                ChecklistItem.newBuilder()
                    .setId(id)
                    .setTitle(title)
                    .setChecked(false)
                    .setOrder(order)
                    .build()
            }
        }
    }
}
