/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.database

import androidx.room.Database
import androidx.room.RoomDatabase
import androidx.room.TypeConverters
import dk.nsp.mingraviditet.database.dao.ArticleCategoryDao
import dk.nsp.mingraviditet.database.dao.ArticleDao
import dk.nsp.mingraviditet.database.dao.ArticleSectionDao
import dk.nsp.mingraviditet.database.dao.CareplanActivityDao
import dk.nsp.mingraviditet.database.model.ArticleCategoryEntity
import dk.nsp.mingraviditet.database.model.ArticleEntity
import dk.nsp.mingraviditet.database.model.ArticleSectionEntity
import dk.nsp.mingraviditet.database.model.CareplanActivityEntity
import dk.nsp.mingraviditet.database.utils.Converters

@Database(
    entities = [
        ArticleCategoryEntity::class,
        ArticleEntity::class,
        ArticleSectionEntity::class,
        CareplanActivityEntity::class,
    ],
    version = 1,
    exportSchema = true,
)
@TypeConverters(
    Converters::class,
)
abstract class MinGraviditetDatabase : RoomDatabase() {
    abstract fun articleCategoryDao(): ArticleCategoryDao
    abstract fun articleDao(): ArticleDao
    abstract fun articleSectionDao(): ArticleSectionDao
    abstract fun careplanActivityDao(): CareplanActivityDao
}
