/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.database.dao

import androidx.room.Dao
import androidx.room.Insert
import androidx.room.OnConflictStrategy
import androidx.room.Query
import androidx.room.Transaction
import androidx.room.Upsert
import dk.nsp.mingraviditet.database.model.ArticleCategoryEntity
import dk.nsp.mingraviditet.database.model.ArticleCategoryWithArticleCountEntity
import dk.nsp.mingraviditet.database.model.PopulatedCategoryEntity
import kotlinx.coroutines.flow.Flow

@Dao
interface ArticleCategoryDao {
    @Upsert
    suspend fun upsertArticleCategories(entities: List<ArticleCategoryEntity>)

    @Transaction
    @Query(
        value = """
            SELECT * FROM article_category ORDER BY category_order ASC
        """,
    )
    fun getArticleCategories(): Flow<List<ArticleCategoryEntity>>

    @Insert(onConflict = OnConflictStrategy.REPLACE)
    suspend fun insertOrReplaceArticleCategories(articleCategories: List<ArticleCategoryEntity>)

    @Insert(onConflict = OnConflictStrategy.REPLACE)
    suspend fun insertArticleCategory(articleCategory: ArticleCategoryEntity)

    @Transaction
    @Query(
        value = """
        SELECT article_category.*,COUNT(article.id) AS articleCount FROM article_category LEFT JOIN article ON article.category_id = article_category.id GROUP BY article_category.id
    """,
    )
    fun getArticleCategoriesWithArticleCount(): Flow<List<ArticleCategoryWithArticleCountEntity>>

    @Transaction
    @Query(
        value = """
            SELECT * FROM article_category WHERE id == :categoryId
        """,
    )
    fun getPopulatedCategory(categoryId: Int): Flow<PopulatedCategoryEntity>
}
