/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.domain.repository

import dk.nsp.api.cms.CMSDataSource
import dk.nsp.domain.pages.Page
import dk.nsp.domain.pages.toDomainModel
import dk.nsp.shared.network.Dispatcher
import dk.nsp.shared.network.MGDispatchers
import dk.nsp.shared.network.ResultWrapper
import dk.nsp.shared.network.mapSuccessWithTryOrFailed
import kotlinx.coroutines.CoroutineDispatcher
import kotlinx.coroutines.withContext
import javax.inject.Inject

class SettingsPagesRepository @Inject constructor(
    private val cmsDataSource: CMSDataSource,
    @Dispatcher(MGDispatchers.IO) private val ioDispatcher: CoroutineDispatcher,
) {
    suspend fun getPage(path: String): ResultWrapper<Page> = withContext(ioDispatcher) {
        cmsDataSource.getPageContent(path).mapSuccessWithTryOrFailed { it.toDomainModel() }
    }
}
