/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021-2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.domain.repository

import dk.nsp.api.cms.CMSDataSource
import dk.nsp.api.cms.models.NetworkFAQItem
import dk.nsp.shared.network.Failed
import dk.nsp.shared.network.toSuccess
import io.mockk.coEvery
import io.mockk.mockk
import java.time.LocalDateTime

class FAQRepositoryTest {

    private val mockedDataSource = mockk<CMSDataSource> {
        coEvery {
            getFAQ()
        } returns listOf(
            NetworkFAQItem(
                "FAQ1",
                "Text1",
                LocalDateTime.now(),
            ),
            NetworkFAQItem(
                "FAQ2",
                "Text2",
                LocalDateTime.now(),
            ),
        ).toSuccess()
    }

    private val failingDataSource = mockk<CMSDataSource> {
        coEvery {
            getFAQ()
        } returns Failed(Exception())
    }

    private fun getRepo(): FAQRepository {
        return FAQRepository(
            cmsDataSource = mockedDataSource,
        )
    }

    private fun getFailingRepo(): FAQRepository {
        return FAQRepository(
            cmsDataSource = failingDataSource,
        )
    }
//
//    @Test
//    fun getFAQs() = runBlocking {
//        getRepo().getFAQs(this)
//            .await()
//            .assertIsAndApply<Success<List<FAQItem>>> {
//                value.size.assertEquals(2)
//                value.getOrNull(0).assertNotNullAndApply {
//                    title.assertEquals("FAQ1")
//                    text.assertEquals("Text1")
//                }
//                value.getOrNull(1).assertNotNullAndApply {
//                    title.assertEquals("FAQ2")
//                    text.assertEquals("Text2")
//                }
//            }
//
//        getFailingRepo().getFAQs(this).await()
//            .assertIs<Failed>()
//    }
}
