/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021-2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.domain.repository

import dk.nsp.api.cms.CMSDataSource
import dk.nsp.api.cms.models.NetworkPage
import dk.nsp.domain.pages.Page
import dk.nsp.mingraviditet.model.misc.SettingSubSectionUrl
import dk.nsp.shared.network.Failed
import dk.nsp.shared.network.Success
import dk.nsp.shared.network.toSuccess
import dk.nsp.testassertions.assertEquals
import dk.nsp.testassertions.assertIs
import dk.nsp.testassertions.assertIsAndApply
import io.mockk.coEvery
import io.mockk.mockk
import kotlinx.coroutines.runBlocking
import org.junit.jupiter.api.Test

class SettingsPagesRepositoryTest {

    private val mockedController = mockk<CMSDataSource> {
        coEvery {
            getPageContent(
                SettingSubSectionUrl.WhoIsBehindTheApp.path,
            )
        } returns Failed(Exception("Could not get info about the app"))

        coEvery {
            getPageContent(
                SettingSubSectionUrl.Consent.path,
            )
        } returns NetworkPage(
            "content test",
        ).toSuccess()
    }

    private fun getRepo(): SettingsPagesRepository {
        return SettingsPagesRepository(mockedController)
    }

    @Test
    fun getPage() = runBlocking {
        val repo = getRepo()

        repo.getPage(SettingSubSectionUrl.WhoIsBehindTheApp.path)
            .assertIs<Failed>()

        repo.getPage(SettingSubSectionUrl.Consent.path)
            .assertIsAndApply<Success<Page>> {
                value.content.assertEquals("content test")
            }
    }
}
