/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.gravidcompose.component

import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Button
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.ColorScheme
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextOverflow
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.tooling.preview.PreviewParameter
import androidx.compose.ui.unit.dp
import dk.nsp.mingraviditet.gravidcompose.theme.GravidTheme
import dk.nsp.mingraviditet.gravidcompose.utils.PreviewColorSchemeProvider

@Composable
fun GravidButton(
    modifier: Modifier = Modifier,
    onClick: () -> Unit,
    text: CharSequence,
    containerColor: Color = GravidTheme.colorScheme.primary,
    textColor: Color = GravidTheme.colorScheme.onPrimary,
    enabled: Boolean = true,
) {
    Button(
        modifier = modifier,
        enabled = enabled,
        onClick = onClick,
        colors = ButtonDefaults.buttonColors(
            containerColor = containerColor,
        ),
        shape = RoundedCornerShape(8.dp),
    ) {
        GravidText(
            text = text,
            style = TextStyle(fontWeight = FontWeight.Bold),
            maxLines = 1,
            overflow = TextOverflow.Ellipsis,
            color = textColor,
        )
    }
}

@Preview(showBackground = true)
@Composable
fun GravidButtonPreview(
    @PreviewParameter(PreviewColorSchemeProvider::class) colorScheme: ColorScheme,
) {
    GravidTheme(overrideColorScheme = colorScheme) {
        Column(
            modifier = Modifier
                .background(GravidTheme.colorScheme.background)
                .padding(GravidTheme.dimens.largeSpacing),
            verticalArrangement = Arrangement.spacedBy(16.dp),
        ) {
            GravidButton(onClick = {}, text = "Button Label")

            GravidButton(
                modifier = Modifier.fillMaxWidth(),
                onClick = {},
                text = "Inverted button",
                containerColor = GravidTheme.colorScheme.onPrimaryContainer,
                textColor = GravidTheme.colorScheme.primaryContainer,
            )
        }
    }
}
