/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.gravidcompose.component

import androidx.compose.animation.AnimatedVisibility
import androidx.compose.animation.fadeIn
import androidx.compose.animation.fadeOut
import androidx.compose.foundation.BorderStroke
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButtonDefaults
import androidx.compose.material3.OutlinedIconToggleButton
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Modifier
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.unit.dp
import dk.nsp.mingraviditet.gravidcompose.theme.GravidTheme
import dk.nsp.mingraviditet.gravidcompose.utils.GravidPreview
import dk.nsp.mingraviditet.ui_compose.R

@Composable
fun GravidCheckbox(
    checked: Boolean,
    onCheckedChanged: (Boolean) -> Unit,
    modifier: Modifier = Modifier,
) {
    var checkedState by remember { mutableStateOf(checked) }

    OutlinedIconToggleButton(
        border = BorderStroke(2.dp, GravidTheme.colorScheme.primary),
        checked = checkedState,
        onCheckedChange = {
            checkedState = it
            onCheckedChanged(it)
        },
        colors = IconButtonDefaults.outlinedIconToggleButtonColors(
            containerColor = GravidTheme.colorScheme.surface,
            contentColor = GravidTheme.colorScheme.primary,
            checkedContainerColor = GravidTheme.colorScheme.primary,
            checkedContentColor = GravidTheme.colorScheme.onPrimary,
        ),
        modifier = modifier,
    ) {
        AnimatedVisibility(visible = checkedState, enter = fadeIn(), exit = fadeOut()) {
            if (checkedState) {
                Icon(
                    modifier = Modifier.fillMaxSize(0.75f),
                    painter = painterResource(id = R.drawable.ic_check),
                    contentDescription = null,
                )
            }
        }
    }
}

@GravidPreview
@Composable
private fun GravidCheckboxPreview() {
    var checkedState by remember { mutableStateOf(false) }

    GravidTheme {
        Column(
            modifier = Modifier.background(GravidTheme.colorScheme.surface),
            verticalArrangement = Arrangement.spacedBy(16.dp),
        ) {
            GravidCheckbox(checked = checkedState, onCheckedChanged = { checkedState = it })
            GravidCheckbox(checked = !checkedState, onCheckedChanged = { checkedState = it })
        }
    }
}
