/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.gravidcompose.component

import androidx.annotation.DrawableRes
import androidx.compose.foundation.BorderStroke
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.PaddingValues
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.ButtonDefaults
import androidx.compose.material3.Icon
import androidx.compose.material3.OutlinedButton
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.text.style.TextOverflow
import androidx.compose.ui.unit.dp
import dk.nsp.mingraviditet.gravidcompose.theme.GravidTheme
import dk.nsp.mingraviditet.gravidcompose.utils.GravidPreview

@Composable
fun GravidOutlinedButton(
    onClick: () -> Unit,
    text: CharSequence,
    modifier: Modifier = Modifier,
    contentPadding: PaddingValues = PaddingValues(
        horizontal = GravidTheme.dimens.largerSpacing,
        vertical = GravidTheme.dimens.largeSpacing,
    ),
    contentColor: Color = GravidTheme.colorScheme.tertiary,
    @DrawableRes trailingIcon: Int? = null,
) {
    OutlinedButton(
        modifier = modifier,
        border = BorderStroke(width = 1.dp, color = contentColor),
        colors = ButtonDefaults.outlinedButtonColors(containerColor = GravidTheme.colorScheme.surface),
        shape = RoundedCornerShape(8.dp),
        contentPadding = contentPadding,
        onClick = onClick,
    ) {
        Row(
            verticalAlignment = Alignment.CenterVertically,
            horizontalArrangement = Arrangement.spacedBy(GravidTheme.dimens.defaultSpacing),
        ) {
            GravidText(
                text = text,
                maxLines = 1,
                overflow = TextOverflow.Ellipsis,
                color = contentColor,
                style = GravidTheme.typography.Header4,
            )

            trailingIcon?.let {
                Icon(
                    painter = painterResource(id = trailingIcon),
                    contentDescription = null,
                    tint = contentColor,
                )
            }
        }
    }
}

@GravidPreview
@Composable
fun GravidOutlinedButtonPreview() {
    GravidTheme {
        Column(
            Modifier
                .background(GravidTheme.colorScheme.background)
                .padding(GravidTheme.dimens.largeSpacing),
            verticalArrangement = Arrangement.spacedBy(16.dp),
            horizontalAlignment = Alignment.CenterHorizontally,
        ) {
            GravidOutlinedButton(
                text = "Test button with icon",
                onClick = {
                },
                trailingIcon = android.R.drawable.ic_input_add,
            )

            GravidOutlinedButton(
                text = "Test button",
                onClick = {
                },
            )
        }
    }
}
