/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.gravidcompose.component

import androidx.compose.foundation.layout.RowScope
import androidx.compose.material3.NavigationBar
import androidx.compose.material3.NavigationBarItem
import androidx.compose.material3.NavigationBarItemDefaults
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.compose.ui.unit.dp
import dk.nsp.mingraviditet.gravidcompose.theme.GravidTheme

@Composable
fun MinGraviditetNavigationBar(
    modifier: Modifier = Modifier,
    content: @Composable RowScope.() -> Unit,
) {
    NavigationBar(
        modifier = modifier,
        containerColor = MinGraviditetNavigationDefaults.navigationContainerColor(),
        contentColor = MinGraviditetNavigationDefaults.navigationContentColor(),
        tonalElevation = 0.dp,
        content = content,
    )
}

@Composable
fun RowScope.MinGraviditetNavigationBarItem(
    selected: Boolean,
    onClick: () -> Unit,
    icon: @Composable () -> Unit,
    modifier: Modifier = Modifier,
    selectedIcon: @Composable () -> Unit = icon,
    enabled: Boolean = true,
    label: @Composable (() -> Unit)? = null,
    alwaysShowLabel: Boolean = true,
) {
    NavigationBarItem(
        selected = selected,
        onClick = onClick,
        icon = if (selected) selectedIcon else icon,
        label = label,
        colors = NavigationBarItemDefaults.colors(
            selectedIconColor = MinGraviditetNavigationDefaults.navigationSelectedItemColor(),
            unselectedIconColor = MinGraviditetNavigationDefaults.navigationContentColor(),
            selectedTextColor = MinGraviditetNavigationDefaults.navigationSelectedItemColor(),
            unselectedTextColor = MinGraviditetNavigationDefaults.navigationContentColor(),
            indicatorColor = MinGraviditetNavigationDefaults.navigationIndicatorColor(),
        ),
        enabled = enabled,
        modifier = modifier,
        alwaysShowLabel = alwaysShowLabel,
    )
}

/**
 * Min Graviditet navigation default values.
 */
object MinGraviditetNavigationDefaults {
    @Composable
    fun navigationContentColor() = GravidTheme.colorScheme.onSurfaceVariant

    @Composable
    fun navigationSelectedItemColor() = GravidTheme.colorScheme.onPrimaryContainer

    @Composable
    fun navigationIndicatorColor() = GravidTheme.colorScheme.primaryContainer

    @Composable
    fun navigationContainerColor() = GravidTheme.colorScheme.surface
}
