/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.gravidcompose.extensions

import androidx.compose.ui.graphics.Color
import androidx.compose.ui.text.AnnotatedString
import androidx.compose.ui.text.SpanStyle
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.buildAnnotatedString
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.text.style.TextDecoration
import androidx.compose.ui.text.withStyle

val AnnotatedString.bold: AnnotatedString
    get() = fontWeight(FontWeight.Bold)

val AnnotatedString.normal: AnnotatedString
    get() = fontWeight(FontWeight.Normal)

fun AnnotatedString.color(color: Color): AnnotatedString {
    return buildAnnotatedString {
        withStyle(style = SpanStyle(color = color)) {
            append(this@color)
        }
    }
}

fun AnnotatedString.fontWeight(fontWeight: FontWeight): AnnotatedString {
    return buildAnnotatedString {
        withStyle(style = SpanStyle(fontWeight = fontWeight)) {
            append(this@fontWeight)
        }
    }
}

fun AnnotatedString.textDecoration(textDecoration: TextDecoration): AnnotatedString {
    return buildAnnotatedString {
        withStyle(style = SpanStyle(textDecoration = textDecoration)) {
            append(this@textDecoration)
        }
    }
}

fun AnnotatedString.textStyle(textStyle: TextStyle): AnnotatedString {
    return buildAnnotatedString {
        withStyle(
            style = SpanStyle(
                color = textStyle.color,
                fontSize = textStyle.fontSize,
                fontWeight = textStyle.fontWeight,
                fontStyle = textStyle.fontStyle,
                fontSynthesis = textStyle.fontSynthesis,
                fontFamily = textStyle.fontFamily,
                fontFeatureSettings = textStyle.fontFeatureSettings,
                letterSpacing = textStyle.letterSpacing,
                baselineShift = textStyle.baselineShift,
                textGeometricTransform = textStyle.textGeometricTransform,
                localeList = textStyle.localeList,
                background = textStyle.background,
                textDecoration = textStyle.textDecoration,
                shadow = textStyle.shadow,
            ),
        ) {
            append(this@textStyle)
        }
    }
}
