/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.gravidcompose.theme

import androidx.compose.ui.graphics.Color

// Support shades
val Jacksons = Color(0xFF2A1983)
val BlueMarguerite = Color(0xFF766BCB)
val MoonRaker = Color(0xFFE0DDF8)
val BlueViolet = Color(0xFF5548BC)
val Tango = Color(0xFFE87613)
val Persimmon = Color(0xFFFF5C50)
val Oracle = Color(0xFF336C71)
val BreakerBay = Color(0xFF69A1AC)
val HalfBaked = Color(0xFF89C5CC)
val AquaIsland = Color(0xFFA9D5DB)

// Dark mode?
val Oxford = Color(0xFF393D5E)
val Fjord = Color(0xFF454A6F)
val Comet = Color(0xFF646887)
val Mirage = Color(0xFF1C1E36)
val Logan = Color(0xFFB3B3CE)

// Warnings
val Alizarin = Color(0xFFDB2721)

// Neutrals
val Grey00 = Color(0xFFFBFAFB)
val Grey01 = Color(0xFFF2F1F4)
val Grey02 = Color(0xFFE8E7EC)
val Grey03 = Color(0xFFDDDDE4)

// Primary
val PurpleHeart = Color(0xFF4228C4)
val Electric = Color(0xFF684AFF)

// Identity
val Tree_poppy = Color(0xFFFF9B21)
val Ming = Color(0xFF3E7F85)
val Botticelli = Color(0xFFC6E3E7)

// Text
val Martinique = Color(0xFF272A48)
val Snow = Color(0xFFFFFFFF)
val Dolphin = Color(0xFF646383)
val Suit = Color(0xFFC1C1CE)

// Overview widget
val Nude = Color(0xFFEFB594)
val TranslucentPurple = Color(0x66631C86)

// These colors don't care if you're in light or dark mode.
// Use only when static colors are needed between schemes.
data class GravidColorSystem(
    val primary: Primary = Primary(),
    val identity: Identity = Identity(),
    val neutrals: Neutrals = Neutrals(),
    val supportShades: SupportShades = SupportShades(),
    val text: Text = Text(),
    val overviewWidget: OverviewWidget = OverviewWidget(),
    val darkMode: DarkMode = DarkMode(),
) {
    data class Primary(
        val purpleHeart: Color = PurpleHeart,
        val electric: Color = Electric,
    )

    data class Identity(
        val treePoppy: Color = Tree_poppy,
        val ming: Color = Ming,
        val botticelli: Color = Botticelli,
    )

    data class Neutrals(
        val grey00: Color = Grey00,
        val grey01: Color = Grey01,
        val grey02: Color = Grey02,
        val grey03: Color = Grey03,
        val white: Color = Snow,
    )

    data class SupportShades(
        val jacksons: Color = Jacksons,
        val blueMarguerite: Color = BlueMarguerite,
        val moonRaker: Color = MoonRaker,
        val blueViolet: Color = BlueViolet,
        val tango: Color = Tango,
        val persimmon: Color = Persimmon,
        val oracle: Color = Oracle,
        val breakerBay: Color = BreakerBay,
        val halfBaked: Color = HalfBaked,
        val aquaIsland: Color = AquaIsland,
    )

    data class Text(
        val martinique: Color = Martinique,
        val dolphin: Color = Dolphin,
        val suit: Color = Suit,
    )

    data class OverviewWidget(
        val wombTop: Color = Snow,
        val wombBottom: Color = Nude,
        val innerDropShadow: Color = TranslucentPurple,
    )

    data class DarkMode(
        val fjord: Color = Fjord,
        val oxford: Color = Oxford,
        val comet: Color = Comet,
        val mirage: Color = Mirage,
        val logan: Color = Logan,
    )
}
