/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2023 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.nsp.mingraviditet.gravidcompose.theme

import androidx.compose.material3.ColorScheme
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.text.font.Font
import androidx.compose.ui.text.font.FontFamily
import androidx.compose.ui.text.font.FontStyle
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.unit.sp
import dk.nsp.mingraviditet.ui_compose.R

val ptSansFamily = FontFamily(
    Font(R.font.ptsans_regular),
    Font(R.font.ptsans_bold, weight = FontWeight.Bold),
    Font(R.font.ptsans_bold_italic, weight = FontWeight.Bold, style = FontStyle.Italic),
    Font(R.font.ptsans_italic, style = FontStyle.Italic),
)

data class GravidTypography(
    private val colors: ColorScheme,
    private val dimens: GravidDimens,
    private val fontFamily: FontFamily,

    val Hero: TextStyle = TextStyle(
        fontFamily = fontFamily,
        fontSize = dimens.fontHero,
        color = colors.onBackground,
        fontWeight = FontWeight.Bold,
    ),
    val Header1: TextStyle = TextStyle(
        fontFamily = fontFamily,
        fontSize = dimens.fontHeader1,
        color = colors.onBackground,
        lineHeight = 28.sp,
        fontWeight = FontWeight.Bold,
    ),
    val Header2: TextStyle = TextStyle(
        fontFamily = fontFamily,
        fontSize = dimens.fontHeader2,
        color = colors.onBackground,
        fontWeight = FontWeight.Bold,
    ),
    val Header3: TextStyle = TextStyle(
        fontFamily = fontFamily,
        fontSize = dimens.fontHeader3,
        color = colors.onBackground,
        lineHeight = 22.sp,
        fontWeight = FontWeight.Bold,
    ),
    val Header4: TextStyle = TextStyle(
        fontFamily = fontFamily,
        fontSize = dimens.fontHeader4,
        color = colors.onBackground,
        fontWeight = FontWeight.Bold,
    ),
    val Header5: TextStyle = TextStyle(
        fontFamily = fontFamily,
        fontSize = dimens.fontHeader5,
        color = colors.onBackground,
        lineHeight = 18.sp,
        fontWeight = FontWeight.Bold,
    ),
    val Info: TextStyle = TextStyle(
        fontFamily = fontFamily,
        fontSize = dimens.fontInfo,
        color = colors.onBackground,
        lineHeight = 18.sp,
    ),
    val BodyStandard: TextStyle = TextStyle(
        fontFamily = fontFamily,
        fontSize = dimens.fontBodyStandard,
        color = colors.onBackground,
        lineHeight = 22.sp,
    ),
    val BodySmall: TextStyle = TextStyle(
        fontFamily = fontFamily,
        fontSize = dimens.fontBodySmall,
        color = colors.onBackground,
    ),
)
